@@ -7,6 +7,13 @@ test_that("Basic ops on usarrests task", {
   expect_identical(task$target_names, character(0))
 })
 
+test_that("Basic ops on ruspini task", {
+  task = tsk("ruspini")
+  expect_task(task)
+  expect_task_clust(task)
+  expect_identical(task$target_names, character(0))
+})
+
 test_that("0 feature task", {
   b = as_data_backend(data.table(ids = 1:30))
   task = TaskClust$new(id = "zero_feat_task", b)
